SnapchatButtonColors enum

Inheritance
Available extensions

Values

YELLOW → const SnapchatButtonColors

Snapchat Yellow

BLACK → const SnapchatButtonColors

Snapchat Black

WHITE → const SnapchatButtonColors

Snapchat White

GRAY → const SnapchatButtonColors

Snapchat Gray

Properties

color → Color

Available on SnapchatButtonColors, provided by the SnapchatButtonExtension extension

Gets the Button Color value associated with ENUM
no setter
ghost → AssetImage

Available on SnapchatButtonColors, provided by the SnapchatButtonExtension extension

Gets the Image to contrast button color
no setter
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textColor → Color

Available on SnapchatButtonColors, provided by the SnapchatButtonExtension extension

Gets the Text Color to contrast button color
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<SnapchatButtonColors>
A constant List of the values in this enum, in order of their declaration.