SnapchatButtonFontOptions class

Constructors

SnapchatButtonFontOptions({double? fontSize, FontWeight? fontWeight, String? fontFamily, List<String>? fontFamilyFallback, List<FontFeature>? fontFeatures, FontStyle? fontStyle})
Custom Font Options

Properties

fontFamily → String?
Change the Text font family
final
fontFamilyFallback → List<String>?
Change the Text font family fallback(s)
final
fontFeatures → List<FontFeature>?
Change the Text font features
final
fontSize → double?
Change the Text font size
final
fontStyle → FontStyle?
Change the Text font style
final
fontWeight → FontWeight?
Change the Text font weight
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited